betty.ancestry.has_file_references module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.has_file_references module

Tools to build data types that reference files.

class betty.ancestry.has_file_references.HasFileReferences

  Bases: `Entity`

  An entity that has associated `betty.ancestry.file.File` entities.

  __init__(*args: Any, file_references: Iterable[FileReference] | ToManyResolver[FileReference] | None = None, **kwargs: Any)
  file_references

    A bidirectional *-to-many entity type association.